%
%  Этот документ предоставляет пакет 'cmcherald' для
%  оформления статей в Вестнике Московского Университета, серия ВМК.
%


%
%   General info
%

\NeedsTeXFormat{LaTeX2e}[1994/12/01]
\ProvidesClass{cmcherald}
\LoadClass[twoside,11pt]{extarticle}



\RequirePackage[T2A,T1]{fontenc}

%
%   Packages: general purpose
%

\RequirePackage[utf8]{inputenc}
\RequirePackage[english,russian]{babel}
\RequirePackage{indentfirst}
\RequirePackage{afterpage}
\RequirePackage{paralist}
\RequirePackage{url}
\urlstyle{same}
\RequirePackage{textcomp}
\IfFileExists{cite.sty}{\RequirePackage{cite}}{}
\IfFileExists{lastpage.sty}{\RequirePackage{lastpage}}{}
\IfFileExists{mdwlist.sty}{\RequirePackage{mdwlist}}{}
\RequirePackage{bm}
\RequirePackage{graphicx}
\RequirePackage{float}
\RequirePackage[font=small,labelsep=period,bf]{caption}
\RequirePackage[bookmarksnumbered,pdfborder={0 0 0}]{hyperref}


%\captionsetup[figure]{name=Fig.}


%
%   Release info
%

\newcommand{\VOLUME}{V}
\newcommand{\NUMBER}{3}
\newcommand{\YEAR}{2019}
\newcommand{\YEARSHORT}{19}


%
%   Paper, printing area, headers and footers
%

\usepackage[%
    includehead, includefoot,
    paperheight=290mm,
    paperwidth=205mm,
    textwidth=170mm,
    textheight=259mm,%
    left=17mm,%
    top=11mm,%
    right=18mm,%
    bottom=20mm,%
    headsep=0.5cm,%
    headheight=14pt,%
    footskip=0.0cm]{geometry}

\RequirePackage{fancyhdr}
\renewcommand{\headrulewidth}{0.5pt}
\pagestyle{fancy}       %   Default
\fancyhead[LE,RO]{\thepage}
\fancyfoot{}
%\fancyfoot[LE]{ВМУ, вычислительная математика и кибернетика, \No \NUMBER}


\newcommand{\setcolonfont}{\fontsize{9pt}{11pt}\selectfont}
\fancypagestyle{titul}{%    %   For title pages
\fancyhead{}%
\lhead{\setcolonfont ВЕСТН. МОСК. УН-ТА. СЕР. 15. ВЫЧИСЛ. МАТЕМ. И КИБЕРН. \YEAR . \No\ \NUMBER. С. \thepage --\pageref{LastPage}}%

\renewcommand{\footrulewidth}{0.0pt}

}

%
%   Section formatting
%

\usepackage[tiny,compact]{titlesec}
\titleformat{\section}[runin]{\normalfont\bfseries}{\indent{\thesection.}}{0.5em}{}
\titleformat{\subsection}[runin]{\normalfont\bfseries}{\indent{\thesubsection.}}{0.5em}{}
%
%   Packages: math and so
%

\RequirePackage{amssymb}
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{amscd}

%\IfFileExists{soul.sty}{\RequirePackage{soul}}{}
%\IfFileExists{soulutf8.sty}{\RequirePackage{soulutf8}}{}

\ifcsname so\endcsname%
% well, they exists
\else
\newcommand{\so}[1]{#1}
\fi%

%
%   New commands for math
%

%   Many often-used, but absent in LaTeX objects

\DeclareMathOperator{\const}{const}
\DeclareMathOperator{\conv}{conv}
\DeclareMathOperator{\med}{med}
\DeclareMathOperator{\sgn}{sgn}
\DeclareMathOperator{\tr}{tr}
\DeclareMathOperator{\diag}{diag}


\renewcommand{\le}{\leqslant}
\renewcommand{\ge}{\geqslant}

\renewcommand{\leq}{\leqslant}
\renewcommand{\geq}{\geqslant}


%
%   Semi-automatic author system
%
\newcommand{\authors}{\footnotesize}

\newcounter{authorNum}
\setcounter{authorNum}{1}

\newcommand{\addAuthorInfo}[1]{%
\g@addto@macro\authors{\quad $^{\text{\arabic{authorNum}}}$\,#1 \addtocounter{authorNum}{1} \\\phantom{}}%
}

% Non-automatic part :(
\newcommand{\first}{$^1$\,}
\newcommand{\second}{$^2$\,}
\newcommand{\third}{$^3$\,}
\newcommand{\fourth}{$^4$\,}
\newcommand{\also}{\!$^,$}


%
%	Shapka
%
\newcommand{\thepapertitle}{TITLE IS NOT DEFINED}
\newcommand{\theauthorsfull}{FULL AUTHORS ARE NOT DEFINED}
\newcommand{\theauthorsshort}{SHORT AUTHORS ARE NOT DEFINED}
\newcommand{\theauthorsinfo}{{}}
\newcommand{\theabstract}{ABSTRACT IS NOT PROVIDED}
\newcommand{\theudk}{UNKNOWN!}


\newcommand{\paperTitle}[1]{\renewcommand{\thepapertitle}{#1}}
\newcommand{\paperActualTitle}[1]{\renewcommand{\thepapertitle}{#1}}
\newcommand{\paperUdk}[1]{\renewcommand{\theudk}{#1}}
\newcommand{\authorsFull}[1]{\renewcommand{\theauthorsfull}{#1}}
\newcommand{\authorsShort}[1]{\renewcommand{\theauthorsshort}{#1}}
\newcommand{\authorsInfo}[1]{\renewcommand{\theauthorsinfo}{#1}}
\newcommand{\paperAbstract}[1]{\renewcommand{\theabstract}{#1}}
\newcommand{\paperGrant}[1]{\newcommand{\thegrant}{#1}}
\newcommand{\paperKeywords}[1]{\newcommand{\thekeywords}{#1}}

\newcommand{\englishTitle}[1]{}
\newcommand{\englishAuthorsShort}[1]{}
\newcommand{\englishAbstract}[1]{}
\newcommand{\englishKeywords}[1]{}

\newcounter{surnameStyle}

\newcommand{\setSurnameStyleSparse}{\setcounter{surnameStyle}{1}}
\newcommand{\setSurnameStyleNormal}{\setcounter{surnameStyle}{0}}

\setSurnameStyleNormal

\newcommand{\surname}[1]{
\ifcsname so\endcsname%
	\ifnum\the\value{surnameStyle}=1%
		\so{#1}
	\else% 
		#1
	\fi%
\else%
#1
\fi%
}

%
%	Article header
%
\makeatletter
\renewcommand{\maketitle}{%                           
\thispagestyle{titul}
\enlargethispage{-0.2cm}
\vspace*{0.1cm}
\noindent {УДК \theudk }
\vspace*{0.1cm}

%
%   Authors
%
{\large \bf \theauthorsfull}

%
%   Arcticle title
%
\pdfbookmark[1]{Abstract}{AbstractReference}
\parbox[l]{0.9\textwidth}{\begin{flushleft}%
                    \noindent{%
			\ifcsname thegrant\endcsname%
				\Large\bf \MakeUppercase{\thepapertitle}*
			\else%
				\Large\bf \MakeUppercase{\thepapertitle}
			\fi%
			}% noindent 
                \end{flushleft}
}

%
%   Abstract
%

\begin{quotation}
\footnotesize\indent\theabstract
\end{quotation}

%
%	Keywords
%
\ifcsname thekeywords\endcsname%
	\begin{quotation}
	\footnotesize\indent \textit{Ключевые слова}: \thekeywords
	\end{quotation}
\else%
	
\fi

%
%   Appereance commands
%


\fancyhead[LO]{\setcolonfont {\thepapertitle}}
\fancyhead[RE]{\setcolonfont {\theauthorsshort}}

\IfFileExists{page}{\input{page}}{}

%
%   Bottom text: author info
%

\begin{figure}[b]
\makebox[\linewidth]{\rule{1in}{0.4pt}\hfill}
\footnotesize

\authors
\ifcsname thegrant\endcsname%
	\quad* \thegrant\vspace{-1.5mm}
\else%
	\vspace{-5.5mm}
\fi%

\end{figure}

}
\makeatother

%
%   Reference commands
%

\renewcommand{\refname}{\begin{center}{СПИСОК ЛИТЕРАТУРЫ}\end{center}}

\newcommand{\source}{\item}
\newcommand{\bibauthor}[1]{\so{#1}}

\newenvironment{references}%
	{\def\section*{\center{СПИСОК ЛИТЕРАТУРЫ}}%
	\pdfbookmark[1]{References}{ReferenceToReferences}
	\renewcommand{\refname}{}%
	%\begin{center}\textbf{REFERENCES}\end{center}%
	\begin{thebibliography}{00}}%
        {\end{thebibliography}\vspace{0.5cm}}

%   No brackets, just number
\makeatletter
\renewcommand\@biblabel[1]{#1.}
\makeatother

%   Shorten the spaces
\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
  \small
  \oldbibliography{#1}%
  \setlength{\itemsep}{-1.4pt}%
}


%
%   Theorems via AMS package
%

\newtheoremstyle{cmchTheorem}% name of the style to be used
  {3pt}% measure of space to leave above the theorem. E.g.: 3pt
  {3pt}% measure of space to leave below the theorem. E.g.: 3pt
  {\itshape}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{cmchRemark}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{cmchDefinition}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {.}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{cmchDotlessTheorem}% name of the style to be used
  {3pt}% measure of space to leave above the theorem. E.g.: 3pt
  {3pt}% measure of space to leave below the theorem. E.g.: 3pt
  {\itshape}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\newtheoremstyle{cmchDotlessDefinition}% name of the style to be used
  {2pt}% measure of space to leave above the theorem. E.g.: 3pt
  {2pt}% measure of space to leave below the theorem. E.g.: 3pt
  {}% name of font to use in the body of the theorem
  {\parindent}% measure of space to indent
  {}% name of head font
  {}% punctuation between head and body
  {.5em}% space after theorem head; " " = normal interword space
  {}

\renewenvironment{proof}{Д\,о\,к\,а\,з\,а\,т\,е\,л\,ь\,с\,т\,в\,о.}{\par}

\theoremstyle{cmchTheorem}
\newtheorem{theorem}{Т\,е\,о\,р\,е\,м\,а}
\newtheorem{statement}{У\,т\,в\,е\,р\,ж\,д\,е\,н\,и\,е}
\newtheorem{lemma}{Л\,е\,м\,м\,а}
\newtheorem{corollary}{С\,л\,е\,д\,с\,т\,в\,и\,е}
\newtheorem{proposition}{П\,р\,е\,д\,л\,о\,ж\,е\,н\,и\,е}

\newtheorem*{theorem*}{Т\,е\,о\,р\,е\,м\,а}
\newtheorem*{statement*}{У\,т\,в\,е\,р\,ж\,д\,е\,н\,и\,е}
\newtheorem*{lemma*}{Л\,е\,м\,м\,а}
\newtheorem*{corollary*}{С\,л\,е\,д\,с\,т\,в\,и\,е}
\newtheorem*{proposition*}{П\,р\,е\,д\,л\,о\,ж\,е\,н\,и\,е}

\theoremstyle{cmchDefinition}
\newtheorem{definition}{О\,п\,р\,е\,д\,е\,л\,е\,н\,и\,е}


%
%   Duplicate the symbol after the '\HM' command on the next line
%
\newcommand*{\HM}[1]{#1\nobreak\discretionary{}{\hbox{\(\mathsurround=0pt #1\)}}{}}

\newcommand{\No}{\textnumero}

\newcommand{\articleColonName}[1]{\fancyhead[LO]{\setcolonfont #1}}

\newcommand{\ENGLISH}[1]{\selectlanguage{english}#1\selectlanguage{russian}}

%
%	Page accounting
%

\newcommand{\timelineInfo}[1]{\noindent\hbox to 0.5\textwidth{}{\small #1}}
%\renewcommand{\baselinestretch}{2}
